##  Searching and Applying Filters
Searching for a filter lets you easily find and apply the right filter. You can search for a specific filter by clicking Add Filter button ( '+' icon when a filter is already applied) in the filter bar of inventory.
![Searching and Applying a Filter](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2744eaea7a441014ae94c5b527d0eec3_LowRes.gif)
Searching and Applying a Filter
